@@ -1,6 +1,7 @@
 import socket
 import logging
 import time
+import ast
 from datetime import datetime
 from flumelogger.eventserver import FlumeEventServer
 from flumelogger.flumeng.ttypes import ThriftFlumeEvent as ThriftFlumeNGEvent
@@ -54,7 +55,7 @@ class FlumeHandler(logging.Handler):
         try:
             self.body = self.format(record)
             try:
-                msg = eval(self.body)
+                msg = ast.literal_eval(self.body)
             except:
                 msg = None
 
